==> hinemos_src-2.4.3.tar.gz: Hinemos_src-2.4.3/Performance/src/com/clustercontrol/performance/monitor/action/GetPerformanceListTableDefine.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.monitor.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Locale;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.performance.monitor.util.EjbConnectionManager;
import com.clustercontrol.performanceMGR.monitor.ejb.session.MonitorPerfController;
import com.clustercontrol.util.Messages;


/**
 * リソース監視一覧テーブル定義情報を取得するクラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetPerformanceListTableDefine {

    /**
     * 閾値監視一覧のテーブル定義情報を返します。
     * 
     * @return 閾値監視一覧テーブル定義情報
     */
    public static ArrayList get() {
    	MonitorPerfController ctr = EjbConnectionManager.getConnectionManager()
                .getMonitorPerfController();

        ArrayList tableDefine = null;
        try {
            tableDefine = ctr.getPerformanceListTableDefine(Locale.getDefault());
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        }
        return tableDefine;
    }
}

==> hinemos_src-3.0.3.tar.gz: Hinemos_src-3.0.3/Performance/src/com/clustercontrol/performance/monitor/action/GetPerformanceListTableDefine.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.monitor.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Locale;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.performance.monitor.util.EjbConnectionManager;
import com.clustercontrol.performance.monitor.ejb.session.MonitorPerfController;
import com.clustercontrol.util.Messages;


/**
 * リソース監視一覧テーブル定義情報を取得するクラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetPerformanceListTableDefine {

    /**
     * 閾値監視一覧のテーブル定義情報を返します。
     * 
     * @return 閾値監視一覧テーブル定義情報
     */
    public static ArrayList get() {
    	MonitorPerfController ctr = EjbConnectionManager.getConnectionManager()
                .getMonitorPerfController();

        ArrayList tableDefine = null;
        try {
            tableDefine = ctr.getPerformanceListTableDefine(Locale.getDefault());
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        }
        return tableDefine;
    }
}
